==> sparkautomapper.fhir-0.2.21b16-py3-none-any.whl: spark_auto_mapper_fhir/resources/substance_source_material.py <==
from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

# noinspection PyPackageRequirements
from pyspark.sql.types import StructType, DataType
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.complex_types.meta import Meta
from spark_auto_mapper_fhir.fhir_types.id import FhirId
from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.fhir_resource_base import FhirResourceBase
from spark_fhir_schemas.r4.resources.substancesourcematerial import (
    SubstanceSourceMaterialSchema,
)

if TYPE_CHECKING:
    pass
    # id_ (id)
    # meta (Meta)
    # implicitRules (uri)
    # language (CommonLanguages)
    from spark_auto_mapper_fhir.value_sets.common_languages import CommonLanguagesCode

    # text (Narrative)
    from spark_auto_mapper_fhir.complex_types.narrative import Narrative

    # contained (ResourceContainer)
    from spark_auto_mapper_fhir.complex_types.resource_container import (
        ResourceContainer,
    )

    # extension (Extension)
    from spark_auto_mapper_fhir.extensions.extension import Extension

    # modifierExtension (Extension)
    # sourceMaterialClass (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # Import for CodeableConcept for sourceMaterialClass
    from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode

    # End Import for CodeableConcept for sourceMaterialClass
    # sourceMaterialType (CodeableConcept)
    # Import for CodeableConcept for sourceMaterialType
    # End Import for CodeableConcept for sourceMaterialType
    # sourceMaterialState (CodeableConcept)
    # Import for CodeableConcept for sourceMaterialState
    # End Import for CodeableConcept for sourceMaterialState
    # organismId (Identifier)
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier

    # organismName (string)
    # parentSubstanceId (Identifier)
    # parentSubstanceName (string)
    # countryOfOrigin (CodeableConcept)
    # Import for CodeableConcept for countryOfOrigin
    # End Import for CodeableConcept for countryOfOrigin
    # geographicalLocation (string)
    # developmentStage (CodeableConcept)
    # Import for CodeableConcept for developmentStage
    # End Import for CodeableConcept for developmentStage
    # fractionDescription (SubstanceSourceMaterial.FractionDescription)
    from spark_auto_mapper_fhir.backbone_elements.substance_source_material_fraction_description import (
        SubstanceSourceMaterialFractionDescription,
    )

    # organism (SubstanceSourceMaterial.Organism)
    from spark_auto_mapper_fhir.backbone_elements.substance_source_material_organism import (
        SubstanceSourceMaterialOrganism,
    )

    # partDescription (SubstanceSourceMaterial.PartDescription)
    from spark_auto_mapper_fhir.backbone_elements.substance_source_material_part_description import (
        SubstanceSourceMaterialPartDescription,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class SubstanceSourceMaterial(FhirResourceBase):
    """
    SubstanceSourceMaterial
    substancesourcematerial.xsd
        Source material shall capture information on the taxonomic and anatomical
    origins as well as the fraction of a material that can result in or can be
    modified to form a substance. This set of data elements shall be used to
    define polymer substances isolated from biological matrices. Taxonomic and
    anatomical origins shall be described using a controlled vocabulary as
    required. This information is captured for naturally derived polymers ( .
    starch) and structurally diverse substances. For Organisms belonging to the
    Kingdom Plantae the Substance level defines the fresh material of a single
    species or infraspecies, the Herbal Drug and the Herbal preparation. For
    Herbal preparations, the fraction information will be captured at the
    Substance information level and additional information for herbal extracts
    will be captured at the Specified Substance Group 1 information level. See for
    further explanation the Substance Class: Structurally Diverse and the herbal
    annex.
        If the element is present, it must have either a @value, an @id, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        meta: Optional[Meta] = None,
        implicitRules: Optional[FhirUri] = None,
        language: Optional[CommonLanguagesCode] = None,
        text: Optional[Narrative] = None,
        contained: Optional[FhirList[ResourceContainer]] = None,
        extension: Optional[FhirList[Extension]] = None,
        modifierExtension: Optional[FhirList[Extension]] = None,
        sourceMaterialClass: Optional[CodeableConcept[GenericTypeCode]] = None,
        sourceMaterialType: Optional[CodeableConcept[GenericTypeCode]] = None,
        sourceMaterialState: Optional[CodeableConcept[GenericTypeCode]] = None,
        organismId: Optional[Identifier] = None,
        organismName: Optional[FhirString] = None,
        parentSubstanceId: Optional[FhirList[Identifier]] = None,
        parentSubstanceName: Optional[FhirList[FhirString]] = None,
        countryOfOrigin: Optional[FhirList[CodeableConcept[GenericTypeCode]]] = None,
        geographicalLocation: Optional[FhirList[FhirString]] = None,
        developmentStage: Optional[CodeableConcept[GenericTypeCode]] = None,
        fractionDescription: Optional[
            FhirList[SubstanceSourceMaterialFractionDescription]
        ] = None,
        organism: Optional[SubstanceSourceMaterialOrganism] = None,
        partDescription: Optional[
            FhirList[SubstanceSourceMaterialPartDescription]
        ] = None,
    ) -> None:
        """
            Source material shall capture information on the taxonomic and anatomical
        origins as well as the fraction of a material that can result in or can be
        modified to form a substance. This set of data elements shall be used to
        define polymer substances isolated from biological matrices. Taxonomic and
        anatomical origins shall be described using a controlled vocabulary as
        required. This information is captured for naturally derived polymers ( .
        starch) and structurally diverse substances. For Organisms belonging to the
        Kingdom Plantae the Substance level defines the fresh material of a single
        species or infraspecies, the Herbal Drug and the Herbal preparation. For
        Herbal preparations, the fraction information will be captured at the
        Substance information level and additional information for herbal extracts
        will be captured at the Specified Substance Group 1 information level. See for
        further explanation the Substance Class: Structurally Diverse and the herbal
        annex.
            If the element is present, it must have either a @value, an @id, or extensions

            :param id_: The logical id of the resource, as used in the URL for the resource. Once
        assigned, this value never changes.
            :param meta: The metadata about the resource. This is content that is maintained by the
        infrastructure. Changes to the content might not always be associated with
        version changes to the resource.
            :param implicitRules: A reference to a set of rules that were followed when the resource was
        constructed, and which must be understood when processing the content. Often,
        this is a reference to an implementation guide that defines the special rules
        along with other profiles etc.
            :param language: The base language in which the resource is written.
            :param text: A human-readable narrative that contains a summary of the resource and can be
        used to represent the content of the resource to a human. The narrative need
        not encode all the structured data, but is required to contain sufficient
        detail to make it "clinically safe" for a human to just read the narrative.
        Resource definitions may define what content should be represented in the
        narrative to ensure clinical safety.
            :param contained: These resources do not have an independent existence apart from the resource
        that contains them - they cannot be identified independently, and nor can they
        have their own independent transaction scope.
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the resource. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the resource and that modifies the understanding of the element
        that contains it and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer is allowed to define an extension, there is a set of requirements
        that SHALL be met as part of the definition of the extension. Applications
        processing a resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param sourceMaterialClass: General high level classification of the source material specific to the
        origin of the material.
            :param sourceMaterialType: The type of the source material shall be specified based on a controlled
        vocabulary. For vaccines, this subclause refers to the class of infectious
        agent.
            :param sourceMaterialState: The state of the source material when extracted.
            :param organismId: The unique identifier associated with the source material parent organism
        shall be specified.
            :param organismName: The organism accepted Scientific name shall be provided based on the organism
        taxonomy.
            :param parentSubstanceId: The parent of the herbal drug Ginkgo biloba, Leaf is the substance ID of the
        substance (fresh) of Ginkgo biloba L. or Ginkgo biloba L. (Whole plant).
            :param parentSubstanceName: The parent substance of the Herbal Drug, or Herbal preparation.
            :param countryOfOrigin: The country where the plant material is harvested or the countries where the
        plasma is sourced from as laid down in accordance with the Plasma Master File.
        For “Plasma-derived substances” the attribute country of origin provides
        information about the countries used for the manufacturing of the Cryopoor
        plama or Crioprecipitate.
            :param geographicalLocation: The place/region where the plant is harvested or the places/regions where the
        animal source material has its habitat.
            :param developmentStage: Stage of life for animals, plants, insects and microorganisms. This
        information shall be provided only when the substance is significantly
        different in these stages (e.g. foetal bovine serum).
            :param fractionDescription: Many complex materials are fractions of parts of plants, animals, or minerals.
        Fraction elements are often necessary to define both Substances and Specified
        Group 1 Substances. For substances derived from Plants, fraction information
        will be captured at the Substance information level ( . Oils, Juices and
        Exudates). Additional information for Extracts, such as extraction solvent
        composition, will be captured at the Specified Substance Group 1 information
        level. For plasma-derived products fraction information will be captured at
        the Substance and the Specified Substance Group 1 levels.
            :param organism: This subclause describes the organism which the substance is derived from. For
        vaccines, the parent organism shall be specified based on these subclause
        elements. As an example, full taxonomy will be described for the Substance
        Name: ., Leaf.
            :param partDescription: To do.
        """
        super().__init__(
            resourceType="SubstanceSourceMaterial",
            id_=id_,
            meta=meta,
            implicitRules=implicitRules,
            language=language,
            text=text,
            contained=contained,
            extension=extension,
            modifierExtension=modifierExtension,
            sourceMaterialClass=sourceMaterialClass,
            sourceMaterialType=sourceMaterialType,
            sourceMaterialState=sourceMaterialState,
            organismId=organismId,
            organismName=organismName,
            parentSubstanceId=parentSubstanceId,
            parentSubstanceName=parentSubstanceName,
            countryOfOrigin=countryOfOrigin,
            geographicalLocation=geographicalLocation,
            developmentStage=developmentStage,
            fractionDescription=fractionDescription,
            organism=organism,
            partDescription=partDescription,
        )

    def get_schema(
        self, include_extension: bool
    ) -> Optional[Union[StructType, DataType]]:
        return SubstanceSourceMaterialSchema.get_schema(
            include_extension=include_extension
        )

==> sparkautomapper.fhir-1.0.10-py3-none-any.whl: spark_auto_mapper_fhir/resources/substance_source_material.py <==
from __future__ import annotations
from typing import Optional, TYPE_CHECKING, Union

# noinspection PyPackageRequirements
from pyspark.sql.types import StructType, DataType
from spark_auto_mapper_fhir.fhir_types.list import FhirList
from spark_auto_mapper_fhir.fhir_types.string import FhirString
from spark_auto_mapper_fhir.complex_types.meta import Meta
from spark_auto_mapper_fhir.extensions.extension_base import ExtensionBase
from spark_auto_mapper_fhir.fhir_types.id import FhirId
from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.fhir_resource_base import FhirResourceBase
from spark_fhir_schemas.r4.resources.substancesourcematerial import (
    SubstanceSourceMaterialSchema,
)

if TYPE_CHECKING:
    pass
    # id_ (id)
    # meta (Meta)
    # implicitRules (uri)
    # language (CommonLanguages)
    from spark_auto_mapper_fhir.value_sets.common_languages import CommonLanguagesCode

    # text (Narrative)
    from spark_auto_mapper_fhir.complex_types.narrative import Narrative

    # contained (ResourceContainer)
    from spark_auto_mapper_fhir.complex_types.resource_container import (
        ResourceContainer,
    )

    # extension (Extension)
    # modifierExtension (Extension)
    # sourceMaterialClass (CodeableConcept)
    from spark_auto_mapper_fhir.complex_types.codeable_concept import CodeableConcept

    # Import for CodeableConcept for sourceMaterialClass
    from spark_auto_mapper_fhir.value_sets.generic_type import GenericTypeCode

    # End Import for CodeableConcept for sourceMaterialClass
    # sourceMaterialType (CodeableConcept)
    # Import for CodeableConcept for sourceMaterialType
    # End Import for CodeableConcept for sourceMaterialType
    # sourceMaterialState (CodeableConcept)
    # Import for CodeableConcept for sourceMaterialState
    # End Import for CodeableConcept for sourceMaterialState
    # organismId (Identifier)
    from spark_auto_mapper_fhir.complex_types.identifier import Identifier

    # organismName (string)
    # parentSubstanceId (Identifier)
    # parentSubstanceName (string)
    # countryOfOrigin (CodeableConcept)
    # Import for CodeableConcept for countryOfOrigin
    # End Import for CodeableConcept for countryOfOrigin
    # geographicalLocation (string)
    # developmentStage (CodeableConcept)
    # Import for CodeableConcept for developmentStage
    # End Import for CodeableConcept for developmentStage
    # fractionDescription (SubstanceSourceMaterial.FractionDescription)
    from spark_auto_mapper_fhir.backbone_elements.substance_source_material_fraction_description import (
        SubstanceSourceMaterialFractionDescription,
    )

    # organism (SubstanceSourceMaterial.Organism)
    from spark_auto_mapper_fhir.backbone_elements.substance_source_material_organism import (
        SubstanceSourceMaterialOrganism,
    )

    # partDescription (SubstanceSourceMaterial.PartDescription)
    from spark_auto_mapper_fhir.backbone_elements.substance_source_material_part_description import (
        SubstanceSourceMaterialPartDescription,
    )


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class SubstanceSourceMaterial(FhirResourceBase):
    """
    SubstanceSourceMaterial
    substancesourcematerial.xsd
        Source material shall capture information on the taxonomic and anatomical
    origins as well as the fraction of a material that can result in or can be
    modified to form a substance. This set of data elements shall be used to
    define polymer substances isolated from biological matrices. Taxonomic and
    anatomical origins shall be described using a controlled vocabulary as
    required. This information is captured for naturally derived polymers ( .
    starch) and structurally diverse substances. For Organisms belonging to the
    Kingdom Plantae the Substance level defines the fresh material of a single
    species or infraspecies, the Herbal Drug and the Herbal preparation. For
    Herbal preparations, the fraction information will be captured at the
    Substance information level and additional information for herbal extracts
    will be captured at the Specified Substance Group 1 information level. See for
    further explanation the Substance Class: Structurally Diverse and the herbal
    annex.
        If the element is present, it must have either a @value, an @id, or extensions
    """

    # noinspection PyPep8Naming
    def __init__(
        self,
        *,
        id_: Optional[FhirId] = None,
        meta: Optional[Meta] = None,
        implicitRules: Optional[FhirUri] = None,
        language: Optional[CommonLanguagesCode] = None,
        text: Optional[Narrative] = None,
        contained: Optional[FhirList[ResourceContainer]] = None,
        extension: Optional[FhirList[ExtensionBase]] = None,
        modifierExtension: Optional[FhirList[ExtensionBase]] = None,
        sourceMaterialClass: Optional[CodeableConcept[GenericTypeCode]] = None,
        sourceMaterialType: Optional[CodeableConcept[GenericTypeCode]] = None,
        sourceMaterialState: Optional[CodeableConcept[GenericTypeCode]] = None,
        organismId: Optional[Identifier] = None,
        organismName: Optional[FhirString] = None,
        parentSubstanceId: Optional[FhirList[Identifier]] = None,
        parentSubstanceName: Optional[FhirList[FhirString]] = None,
        countryOfOrigin: Optional[FhirList[CodeableConcept[GenericTypeCode]]] = None,
        geographicalLocation: Optional[FhirList[FhirString]] = None,
        developmentStage: Optional[CodeableConcept[GenericTypeCode]] = None,
        fractionDescription: Optional[
            FhirList[SubstanceSourceMaterialFractionDescription]
        ] = None,
        organism: Optional[SubstanceSourceMaterialOrganism] = None,
        partDescription: Optional[
            FhirList[SubstanceSourceMaterialPartDescription]
        ] = None,
    ) -> None:
        """
            Source material shall capture information on the taxonomic and anatomical
        origins as well as the fraction of a material that can result in or can be
        modified to form a substance. This set of data elements shall be used to
        define polymer substances isolated from biological matrices. Taxonomic and
        anatomical origins shall be described using a controlled vocabulary as
        required. This information is captured for naturally derived polymers ( .
        starch) and structurally diverse substances. For Organisms belonging to the
        Kingdom Plantae the Substance level defines the fresh material of a single
        species or infraspecies, the Herbal Drug and the Herbal preparation. For
        Herbal preparations, the fraction information will be captured at the
        Substance information level and additional information for herbal extracts
        will be captured at the Specified Substance Group 1 information level. See for
        further explanation the Substance Class: Structurally Diverse and the herbal
        annex.
            If the element is present, it must have either a @value, an @id, or extensions

            :param id_: The logical id of the resource, as used in the URL for the resource. Once
        assigned, this value never changes.
            :param meta: The metadata about the resource. This is content that is maintained by the
        infrastructure. Changes to the content might not always be associated with
        version changes to the resource.
            :param implicitRules: A reference to a set of rules that were followed when the resource was
        constructed, and which must be understood when processing the content. Often,
        this is a reference to an implementation guide that defines the special rules
        along with other profiles etc.
            :param language: The base language in which the resource is written.
            :param text: A human-readable narrative that contains a summary of the resource and can be
        used to represent the content of the resource to a human. The narrative need
        not encode all the structured data, but is required to contain sufficient
        detail to make it "clinically safe" for a human to just read the narrative.
        Resource definitions may define what content should be represented in the
        narrative to ensure clinical safety.
            :param contained: These resources do not have an independent existence apart from the resource
        that contains them - they cannot be identified independently, and nor can they
        have their own independent transaction scope.
            :param extension: May be used to represent additional information that is not part of the basic
        definition of the resource. To make the use of extensions safe and manageable,
        there is a strict set of governance  applied to the definition and use of
        extensions. Though any implementer can define an extension, there is a set of
        requirements that SHALL be met as part of the definition of the extension.
            :param modifierExtension: May be used to represent additional information that is not part of the basic
        definition of the resource and that modifies the understanding of the element
        that contains it and/or the understanding of the containing element's
        descendants. Usually modifier elements provide negation or qualification. To
        make the use of extensions safe and manageable, there is a strict set of
        governance applied to the definition and use of extensions. Though any
        implementer is allowed to define an extension, there is a set of requirements
        that SHALL be met as part of the definition of the extension. Applications
        processing a resource are required to check for modifier extensions.

        Modifier extensions SHALL NOT change the meaning of any elements on Resource
        or DomainResource (including cannot change the meaning of modifierExtension
        itself).
            :param sourceMaterialClass: General high level classification of the source material specific to the
        origin of the material.
            :param sourceMaterialType: The type of the source material shall be specified based on a controlled
        vocabulary. For vaccines, this subclause refers to the class of infectious
        agent.
            :param sourceMaterialState: The state of the source material when extracted.
            :param organismId: The unique identifier associated with the source material parent organism
        shall be specified.
            :param organismName: The organism accepted Scientific name shall be provided based on the organism
        taxonomy.
            :param parentSubstanceId: The parent of the herbal drug Ginkgo biloba, Leaf is the substance ID of the
        substance (fresh) of Ginkgo biloba L. or Ginkgo biloba L. (Whole plant).
            :param parentSubstanceName: The parent substance of the Herbal Drug, or Herbal preparation.
            :param countryOfOrigin: The country where the plant material is harvested or the countries where the
        plasma is sourced from as laid down in accordance with the Plasma Master File.
        For “Plasma-derived substances” the attribute country of origin provides
        information about the countries used for the manufacturing of the Cryopoor
        plama or Crioprecipitate.
            :param geographicalLocation: The place/region where the plant is harvested or the places/regions where the
        animal source material has its habitat.
            :param developmentStage: Stage of life for animals, plants, insects and microorganisms. This
        information shall be provided only when the substance is significantly
        different in these stages (e.g. foetal bovine serum).
            :param fractionDescription: Many complex materials are fractions of parts of plants, animals, or minerals.
        Fraction elements are often necessary to define both Substances and Specified
        Group 1 Substances. For substances derived from Plants, fraction information
        will be captured at the Substance information level ( . Oils, Juices and
        Exudates). Additional information for Extracts, such as extraction solvent
        composition, will be captured at the Specified Substance Group 1 information
        level. For plasma-derived products fraction information will be captured at
        the Substance and the Specified Substance Group 1 levels.
            :param organism: This subclause describes the organism which the substance is derived from. For
        vaccines, the parent organism shall be specified based on these subclause
        elements. As an example, full taxonomy will be described for the Substance
        Name: ., Leaf.
            :param partDescription: To do.
        """
        super().__init__(
            resourceType="SubstanceSourceMaterial",
            id_=id_,
            meta=meta,
            implicitRules=implicitRules,
            language=language,
            text=text,
            contained=contained,
            extension=extension,
            modifierExtension=modifierExtension,
            sourceMaterialClass=sourceMaterialClass,
            sourceMaterialType=sourceMaterialType,
            sourceMaterialState=sourceMaterialState,
            organismId=organismId,
            organismName=organismName,
            parentSubstanceId=parentSubstanceId,
            parentSubstanceName=parentSubstanceName,
            countryOfOrigin=countryOfOrigin,
            geographicalLocation=geographicalLocation,
            developmentStage=developmentStage,
            fractionDescription=fractionDescription,
            organism=organism,
            partDescription=partDescription,
        )

    def get_schema(
        self, include_extension: bool
    ) -> Optional[Union[StructType, DataType]]:
        return SubstanceSourceMaterialSchema.get_schema(
            include_extension=include_extension
        )
